Enum2StringFactory<T extends Enum> class

Inheritance

Constructors

Enum2StringFactory()

Properties

converters ↔ Map<Type, Convert>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(Type t) → bool
inherited
getConvert(Type sourceType) → Convert<T, String>
override
getReturnType() → Type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited