AllProperties class

wildcard that matches field values given a source and target type.

Inheritance

Constructors

AllProperties()

Properties

exceptions ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeProperties(Type sourceClass, Type targetClass) → List<String>
override
except(List<String> properties) → AllProperties
remove the field names from the matching process.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited