Convert<S, T> class

Wrapper class for a Converter that preserves the type information.

Constructors

Convert({Converter<S, T>? convertSource, Converter<T, S>? convertTarget, Type? sourceType, Type? targetType})
Create a new Convert instance convert the Converter
const

Properties

convertSourceFunc → Converter<S, T>?
final
convertTargetFunc → Converter<T, S>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → Type
final
targetType → Type
final

Methods

convertSource(S source) → T
convertTarget(T source) → S
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sourceConverter() → Converter
targetConverter() → Converter
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited