Match class

@internal

Constructors

Match({required MapOperation operation, required List<Accessor> source, required List<Accessor> target})

Properties

converter → Convert?
no setter
deep → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
operation → MapOperation
final
paths ↔ List<List<Accessor>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → List<Accessor>
final
target → List<Accessor>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited