Buffer class

@internal

Constructors

Buffer({required IntermediateResultDefinition definition, required int nArgs, required int constructorArgs})

Properties

arrayArguments → List
final
constructor → FromArrayConstructor
final
constructorArgs ↔ int
getter/setter pair
definition → IntermediateResultDefinition
final
hashCode → int
The hash code for this object.
no setterinherited
nArgs ↔ int
getter/setter pair
nSuppliedArgs ↔ int
getter/setter pair
result ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueReceiver → ValueReceiver
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(dynamic instance, dynamic value, Property<MappingContext>? property, int index, MappingContext mappingContext) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited